@@ -3,7 +3,7 @@
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
    * http://www.jus.uio.no/sisu/SiSU/download
- * Description: Document skin sample prepared for Gutenberg Project (first used with "War and Peace") 
+ * Description: Document skin sample prepared for Gutenberg Project (first used with "War and Peace")
  * License: Same as SiSU see http://www.jus.uio.no/sisu
  * Notes: Site default appearance variables set in defaults.rb
      Generic site wide modifications set here scribe_skin.rb, and this file required by other "scribes" instead of defaults.rb
@@ -13,7 +13,7 @@ module SiSU_Viz
   class Skin
     #% path
     def path_root                                                                     # the only parameter that cannot be changed here
-      './sisu/'  
+      './sisu/'
     end
     def path_rel
       '../'
@@ -51,7 +51,7 @@ module SiSU_Viz
     end
     #% credits
     def credits_splash
-      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center><a href="http://www.gutenberg.net/"><img border="0" align="center" src="../_sisu/image_local/gutenberg_icon.png" alt="Gutenberg Project"><br />Courtesy of The Gutenberg Project</a><br />#{widget_sisu}</center></font></td></tr></table>}
+      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center><a href="http://www.gutenberg.net/"><img border="0" align="center" src="../_sisu/image_local/gutenberg_icon.png" alt="Gutenberg Project"><br />Courtesy of The Gutenberg Project</a></center></font></td></tr></table>}
     end
   end
   class TeX
@@ -67,9 +67,6 @@ module SiSU_Viz
     def owner_chapter
       "Document owner details"
     end
-    def stmp
-	    "\\copyright Ralph Amissah, licence GPL \\\\\n www.jus.uio.no/sisu/"
-    end
   end
   class Inserts
     def insert1
