@@ -3,7 +3,7 @@
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
    * http://www.jus.uio.no/sisu/SiSU/download
- * Description: Document skin for "Free For All" 
+ * Description: Document skin for "Free For All"
  * arch-tag: skin for an individual document set (wayner)
  * License: Same as SiSU see http://www.jus.uio.no/sisu
  * $Date$
@@ -36,7 +36,7 @@ module SiSU_Viz
     #end
     #% color
     def color_band1
-      '"#000070"'      
+      '"#000070"'
     end
     #% txt
     def txt_hp
@@ -60,7 +60,7 @@ module SiSU_Viz
     end
     def icon_up
       'arrow_up_blue.png'
-    end    
+    end
     #% banner
     def banner_home_button
       %{<table summary="home button" border="0" cellpadding="3" cellspacing="0"><tr><td align="left" bgcolor=#{color_yellow_dark}><a href="#{url_home}">#{png_home}</a></td></tr></table>\n}
@@ -73,7 +73,7 @@ module SiSU_Viz
     end
     #% credits
     def credits_splash
-      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center>Available at Amazon.com<br /><a href="http://www.amazon.com/exec/obidos/tg/detail/-/0066620503/"><img border="0" align="center" src="../_sisu/image/free.for.all.png" alt="Free For All at Amazon.com"></a><br />This book is Copyright © 2000 by Peter Wayner.<br />See <a href="http://www.wayner.org/books/ffa/">http://www.wayner.org/books/ffa/</a><br /><a href="mailto://p3@wayner.org">p3@wayner.org</a><br />#{widget_sisu}</center></font></td></tr></table>}
+      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center>Available at Amazon.com<br /><a href="http://www.amazon.com/exec/obidos/tg/detail/-/0066620503/"><img border="0" align="center" src="../_sisu/image/free.for.all.png" alt="Free For All at Amazon.com"></a><br />This book is Copyright © 2000 by Peter Wayner.<br />See <a href="http://www.wayner.org/books/ffa/">http://www.wayner.org/books/ffa/</a><br /><a href="mailto://p3@wayner.org">p3@wayner.org</a></center></font></td></tr></table>}
     end
   end
   class TeX
@@ -89,8 +89,6 @@ module SiSU_Viz
     def owner_chapter
       "Document owner details"
     end
-    def stmp
-	    "\\copyright Ralph Amissah, licence GPL \\\\\n www.jus.uio.no/sisu/"
-    end
   end
 end
+__END__
